@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.015-13-g171a56a
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.016-9-gf00f4b0
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use Moose;
 with
@@ -308,7 +308,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
@@ -439,7 +439,8 @@ are now included automatically, when used).
 A number of helper subroutines are available for use within your code inserted
 via C<-raw>, C<-raw_from_file>, or C<-condition> clauses. When used, their
 definition(s) will be included automatically in F<Makefile.PL> (as well as
-those of any other subroutines I<they> call).
+those of any other subroutines I<they> call); necessary prerequisite modules
+will be added to C<configure requires> metadata.
 
 Unless otherwise noted, these all became available in version 0.010.
 Available subs are:
@@ -595,7 +596,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-Plugin-DynamicPrereqs@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-DynamicPrereqs@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 irc://irc.perl.org/#distzilla.
